@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
+Copyright (C) 2015-2020 Layla Marchant <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,10 +28,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 extern Uint32 red;
 extern Uint32 darkRed;
 extern Uint32 yellow;
+extern Uint32 lightYellow;
 extern Uint32 darkYellow;
 extern Uint32 green;
+extern Uint32 lightGreen;
 extern Uint32 darkGreen;
 extern Uint32 blue;
+extern Uint32 lightBlue;
+extern Uint32 lighterBlue;
 extern Uint32 darkBlue;
 extern Uint32 darkerBlue;
 extern Uint32 black;
