@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
+Copyright (C) 2015-2020 Layla Marchant <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -62,7 +62,6 @@ typedef struct Engine_ {
 	int lowShield;
 	int averageShield;
 
-	float targetShield;
 	int targetIndex;
 
 	// Mission completion timer (allows for 4 seconds before leaving sector)
@@ -90,10 +89,16 @@ typedef struct Engine_ {
 	int useMusic;
 	int fullScreen;
 	int autoPause;
+	int radioLife;
+	char lang[STRMAX_SHORT];
 
-	char configDirectory[1024];
+	char configDirectory[PATH_MAX];
 	
-	char keyState[KEY_LAST];
+	int keyState[KEY_LAST];
+	double xaxis;
+	double yaxis;
+	
+	int useController;
 
 	int cheat; // overall cheat
 	int cheatShield;
@@ -108,8 +113,11 @@ extern Engine engine;
 
 void engine_init();
 void engine_showError(int errorId, const char *name);
+void engine_warn(const char *msg);
+void engine_error(const char *msg);
 void engine_setupConfigDirectory();
 void engine_setMode();
+void engine_setFullscreen(int value);
 void engine_resetLists();
 void engine_cleanup();
 
