@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
+Copyright (C) 2015-2020 Layla Marchant <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 extern Planet intermission_planets[MAX_PLANETS];
 
-const int intermission_ycenter = 50 + (SCREEN_HEIGHT - 150) / 2;
+#define INTERMISSION_YCENTER (50 + (screen->h - 150) / 2)
 
 void intermission_initPlanets(int system);
 void intermission_unlockPlanets();
