@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
+Copyright (C) 2015-2020 Layla Marchant <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -25,9 +25,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 extern Object player;
 extern int player_chargerFired;
+extern int player_damageDelay;
+extern int player_resetDamageDelay;
 
 void player_init();
 void player_setTarget(int index);
+void player_damage(int amount, int delay);
 void player_checkShockDamage(float x, float y);
 void player_exit();
 void player_flushInput();
