@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
+Copyright (C) 2015-2020 Layla Marchant <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -30,13 +30,15 @@ extern LinkedRect *screen_bufferHead;
 extern LinkedRect *screen_bufferTail;
 
 void screen_blit(SDL_Surface *image, int x, int y);
-void screen_blitText(int i);
+void screen_blitText(int i, int x, int y);
 int screen_renderString(const char *in, int x, int y, int fontColor);
+int screen_renderUnicode(const char *in, int x, int y, int fontColor);
 void screen_drawBackground();
 void screen_addBuffer(int x, int y, int w, int h);
 void screen_flushBuffer();
 void screen_unBuffer();
 void screen_clear(Uint32 color);
 void screen_drawRect(int x, int y, int w, int h, Uint8 red, Uint8 green, Uint8 blue);
+void screen_adjustDimensions(int w, int h);
 
 #endif
