@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
+Copyright (C) 2015-2020 Layla Marchant <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,6 +23,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "defs.h"
 #include "structs.h"
 
+#define SHOP_WIDTH 600
+#define SHOP_HEIGHT 336
+#define SHOP_X (screen->w / 2 - SHOP_WIDTH / 2)
+#define SHOP_Y (INTERMISSION_YCENTER - SHOP_HEIGHT / 2)
+
 void shop_init();
 void shop_show();
 
